scipy.signal.lti
================

.. currentmodule:: scipy.signal

.. autoclass:: lti

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         lti.impulse
         lti.output
         lti.step



   

